.. _view_module:

:mod:`pyramid.view`
----------------------

.. automodule:: pyramid.view

  .. autofunction:: render_view_to_response

  .. autofunction:: render_view_to_iterable

  .. autofunction:: render_view

  .. autoclass:: view_config
     :members:

  .. autoclass:: view_defaults
     :members:

  .. autoclass:: notfound_view_config
     :members:

  .. autoclass:: forbidden_view_config
     :members:

  .. autoclass:: exception_view_config
     :members:

